package com.codingapi.txlcn.tc.event.transaction;


import com.codingapi.txlcn.tc.info.TransactionInfo;

class DefaultTransactionEventListener implements TransactionEventListener {

 @Override
 public void onBeforeCreateTransaction(TransactionInfo transactionInfo) {

 }

 @Override
 public void onAfterCreateTransaction(TransactionInfo transactionInfo) {

 }

 @Override
 public void onBeforeJoinTransaction(TransactionInfo transactionInfo) {

 }

 @Override
 public void onAfterJoinTransaction(TransactionInfo transactionInfo) {

 }

 @Override
 public void onBeforeNotifyTransaction(TransactionInfo transactionInfo) {

 }

 @Override
 public void onAfterNotifyTransaction(TransactionInfo transactionInfo) {

 }
}
